@@ -9,8 +9,8 @@ use File::Spec;
 
 use MooX qw/late/;
 
-use XML::GrammarBase::Role::RelaxNG;
-use XML::GrammarBase::Role::XSLT v0.2.0;
+use XML::GrammarBase::Role::RelaxNG v0.2.2;
+use XML::GrammarBase::Role::XSLT v0.2.2;
 
 with ('XML::GrammarBase::Role::RelaxNG');
 with XSLT(output_format => 'html');
@@ -31,11 +31,11 @@ XML::Grammar::Fortune - convert the FortunesXML grammar to other formats and fro
 
 =head1 VERSION
 
-Version 0.0510
+Version 0.0511
 
 =cut
 
-our $VERSION = '0.0510';
+our $VERSION = '0.0511';
 
 
 =head1 SYNOPSIS
